package com.sun.xml.internal.fastinfoset.stax.factory;

import com.sun.xml.internal.fastinfoset.stax.events.ProcessingInstructionEvent;
import javax.xml.stream.events.ProcessingInstruction;
import com.sun.xml.internal.fastinfoset.stax.events.DTDEvent;
import javax.xml.stream.events.DTD;
import com.sun.xml.internal.fastinfoset.stax.events.CommentEvent;
import javax.xml.stream.events.Comment;
import com.sun.xml.internal.fastinfoset.stax.events.EntityReferenceEvent;
import javax.xml.stream.events.EntityReference;
import javax.xml.stream.events.EntityDeclaration;
import com.sun.xml.internal.fastinfoset.stax.events.EndDocumentEvent;
import javax.xml.stream.events.EndDocument;
import com.sun.xml.internal.fastinfoset.stax.events.StartDocumentEvent;
import javax.xml.stream.events.StartDocument;
import com.sun.xml.internal.fastinfoset.stax.events.CharactersEvent;
import javax.xml.stream.events.Characters;
import com.sun.xml.internal.fastinfoset.stax.events.EndElementEvent;
import javax.xml.stream.events.EndElement;
import javax.xml.namespace.NamespaceContext;
import com.sun.xml.internal.fastinfoset.stax.events.StartElementEvent;
import javax.xml.stream.events.StartElement;
import java.util.Iterator;
import com.sun.xml.internal.fastinfoset.stax.events.NamespaceBase;
import javax.xml.stream.events.Namespace;
import javax.xml.namespace.QName;
import com.sun.xml.internal.fastinfoset.stax.events.AttributeBase;
import javax.xml.stream.events.Attribute;
import javax.xml.stream.Location;
import javax.xml.stream.XMLEventFactory;

public class StAXEventFactory extends XMLEventFactory
{
    Location location;
    
    public StAXEventFactory() {
        this.location = null;
    }
    
    @Override
    public void setLocation(Location location) {
        this.location = location;
    }
    
    @Override
    public Attribute createAttribute(String prefix, String namespaceURI, String localName, String value) {
        AttributeBase attr = new AttributeBase(prefix, namespaceURI, localName, value, null);
        if (this.location != null) {
            attr.setLocation(this.location);
            return attr;
        }
        return attr;
    }
    
    @Override
    public Attribute createAttribute(String localName, String value) {
        AttributeBase attr = new AttributeBase(localName, value);
        if (this.location != null) {
            attr.setLocation(this.location);
            return attr;
        }
        return attr;
    }
    
    @Override
    public Attribute createAttribute(QName name, String value) {
        AttributeBase attr = new AttributeBase(name, value);
        if (this.location != null) {
            attr.setLocation(this.location);
            return attr;
        }
        return attr;
    }
    
    @Override
    public Namespace createNamespace(String namespaceURI) {
        NamespaceBase event = new NamespaceBase(namespaceURI);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public Namespace createNamespace(String prefix, String namespaceURI) {
        NamespaceBase event = new NamespaceBase(prefix, namespaceURI);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public StartElement createStartElement(QName name, Iterator attributes, Iterator namespaces) {
        return this.createStartElement(name.getPrefix(), name.getNamespaceURI(), name.getLocalPart(), attributes, namespaces);
    }
    
    @Override
    public StartElement createStartElement(String prefix, String namespaceUri, String localName) {
        StartElementEvent event = new StartElementEvent(prefix, namespaceUri, localName);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public StartElement createStartElement(String prefix, String namespaceUri, String localName, Iterator attributes, Iterator namespaces) {
        return this.createStartElement(prefix, namespaceUri, localName, attributes, namespaces, null);
    }
    
    @Override
    public StartElement createStartElement(String prefix, String namespaceUri, String localName, Iterator attributes, Iterator namespaces, NamespaceContext context) {
        StartElementEvent elem = new StartElementEvent(prefix, namespaceUri, localName);
        elem.addAttributes(attributes);
        elem.addNamespaces(namespaces);
        elem.setNamespaceContext(context);
        if (this.location != null) {
            elem.setLocation(this.location);
            return elem;
        }
        return elem;
    }
    
    @Override
    public EndElement createEndElement(QName name, Iterator namespaces) {
        return this.createEndElement(name.getPrefix(), name.getNamespaceURI(), name.getLocalPart(), namespaces);
    }
    
    @Override
    public EndElement createEndElement(String prefix, String namespaceUri, String localName) {
        EndElementEvent event = new EndElementEvent(prefix, namespaceUri, localName);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public EndElement createEndElement(String prefix, String namespaceUri, String localName, Iterator namespaces) {
        EndElementEvent event = new EndElementEvent(prefix, namespaceUri, localName);
        if (namespaces != null) {
            while (namespaces.hasNext()) {
                event.addNamespace((Namespace)namespaces.next());
            }
        }
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public Characters createCharacters(String content) {
        CharactersEvent charEvent = new CharactersEvent(content);
        if (this.location != null) {
            charEvent.setLocation(this.location);
            return charEvent;
        }
        return charEvent;
    }
    
    @Override
    public Characters createCData(String content) {
        CharactersEvent charEvent = new CharactersEvent(content, true);
        if (this.location != null) {
            charEvent.setLocation(this.location);
            return charEvent;
        }
        return charEvent;
    }
    
    @Override
    public Characters createSpace(String content) {
        CharactersEvent event = new CharactersEvent(content);
        event.setSpace(true);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public Characters createIgnorableSpace(String content) {
        CharactersEvent event = new CharactersEvent(content, false);
        event.setSpace(true);
        event.setIgnorable(true);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public StartDocument createStartDocument() {
        StartDocumentEvent event = new StartDocumentEvent();
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public StartDocument createStartDocument(String encoding) {
        StartDocumentEvent event = new StartDocumentEvent(encoding);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public StartDocument createStartDocument(String encoding, String version) {
        StartDocumentEvent event = new StartDocumentEvent(encoding, version);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public StartDocument createStartDocument(String encoding, String version, boolean standalone) {
        StartDocumentEvent event = new StartDocumentEvent(encoding, version);
        event.setStandalone(standalone);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public EndDocument createEndDocument() {
        EndDocumentEvent event = new EndDocumentEvent();
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public EntityReference createEntityReference(String name, EntityDeclaration entityDeclaration) {
        EntityReferenceEvent event = new EntityReferenceEvent(name, entityDeclaration);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
    
    @Override
    public Comment createComment(String text) {
        CommentEvent charEvent = new CommentEvent(text);
        if (this.location != null) {
            charEvent.setLocation(this.location);
            return charEvent;
        }
        return charEvent;
    }
    
    @Override
    public DTD createDTD(String dtd) {
        DTDEvent dtdEvent = new DTDEvent(dtd);
        if (this.location != null) {
            dtdEvent.setLocation(this.location);
            return dtdEvent;
        }
        return dtdEvent;
    }
    
    @Override
    public ProcessingInstruction createProcessingInstruction(String target, String data) {
        ProcessingInstructionEvent event = new ProcessingInstructionEvent(target, data);
        if (this.location != null) {
            event.setLocation(this.location);
            return event;
        }
        return event;
    }
}
